Skip site navigation (1)Skip section navigation (2)

  
 
  

home | help
OWSHELL(1)		      One-Wire File System		      OWSHELL(1)

NAME
     owdir,  owread,  owwrite,	owget, owexist, owpresent - lightweight owserver
     access

SYNOPSIS
   Minimal options
     owdir -s [host:]port [directory]
     owread -s [host:]port filepath
     owwrite -s [host:]port filepath value
     owget -s [host:]port [directory] | filepath

   Server discovery
     owdir --autoserver [directory]
     owread --autoserver filepath
     owwrite --autoserver filepath value
     owget --autoserver [directory] | filepath

   Full options
     owdir -q --quiet -f --format f[.]i[[.]c] ] [ --dir ] -s [host:]port [direc-
     tory] [directory2 ...]

     owread -q --quiet -C --celsius -K --kelvin -F --fahrenheit -R  --rankine  [
     --hex  ]  [  --start=  offset  ]  [ --size= bytes ] -s [host:]port filepath
     [filepath2 ...]

     owwrite -q --quiet -C --celsius -K --kelvin -F --fahrenheit -R --rankine  [
     --hex ] [ --start= offset ] -s [host:]port filepath value [filepath2 value2
     ...]

     owget  -q	--quiet  -f  --format  f[.]i[[.]c]  -C	--celsius -K --kelvin -F
     --fahrenheit -R --rankine [ --hex ] [ --start= offset ] [ --size= bytes ] [
     --dir ] -s [host:]port [directory] | filepath

   Version
     owdir -V --version
     owread -V --version
     owwrite -V --version
     owget -V --version

   Help
     owdir -h | --help
     owread -h | --help
     owwrite -h | --help
     owget -h | --help

DESCRIPTION
   1-Wire
     1-wire is a wiring protocol and series of devices designed and manufactured
     by Dallas Semiconductor, Inc. The bus is a low-power low-speed  low-connec-
     tor scheme where the data line can also provide power.

     Each  device is uniquely and unalterably numbered during manufacture. There
     are a wide variety of devices, including memory, sensors (humidity, temper-
     ature, voltage, contact, current), switches, timers and data loggers.  More
     complex  devices  (like thermocouple sensors) can be built with these basic
     devices. There are also 1-wire devices that have encryption included.

     The 1-wire scheme uses a single bus master and multiple slaves on the  same
     wire.  The  bus master initiates all communication. The slaves can be indi-
     vidually discovered and addressed using their unique ID.

     Bus masters come in a variety of configurations including serial, parallel,
     i2c, network or USB adapters.

   OWFS design
     OWFS is a suite of programs that designed to make the 1-wire  bus	and  its
     devices  easily accessible. The underlying principle is to create a virtual
     filesystem, with the unique ID being  the	directory,  and  the  individual
     properties  of  the device are represented as simple files that can be read
     and written.

     Details of the individual slave or master design are hidden behind  a  con-
     sistent  interface. The goal is to provide an easy set of tools for a soft-
     ware designer to create monitoring or control applications. There are  some
     performance  enhancements	in  the  implementation, including data caching,
     parallel access to bus masters, and aggregation  of  device  communication.
     Still  the  fundamental goal has been ease of use, flexibility and correct-
     ness rather than speed.

   OWSHELL programs
     owdir owread owwrite and owget are collectively  called  the  owshell  pro-
     grams.  They allow lightweight access to an owserver (1) for use in command
     line scripts.

     Unlike owserver (1) owhttpd (1) owftpd (1) owhttpd (1) there is not persis-
     tent connection with the 1-wire bus, no caching and no multithreading.  In-
     stead, each program connects to a running owserver (1) and performs a quick
     set of queries.

     owserver  (1)  performs  the  actual  1-wire connection (to physical 1-wire
     buses or other owserver programs), performs concurrency  locking,	caching,
     and error collection.

     owshell  programs are intended for use in command line scripts. An alterna-
     tive approach is to mount an owfs (1) filesystem and  perform  direct  file
     lists, reads and writes.

   owdir
     owdir  performs  a  directory listing. With no argument, all the devices on
     the main 1-wire bus will be listed. Given the name of a 1-wire device,  the
     available properties will be listed. It is the equivalent of

	    ls directory

     in the owfs (1) filesystem.

   owread
     owread   obtains	for   value   of   a   1-wire	device	 property.  e.g.
     28.0080BE21AA00/temperature gives the DS18B20 temperature. It is the equiv-
     alent of

	    cat filepath

     in the owfs (1) filesystem.

   owwrite
     owwrite performs a change of a property, changing a 1-wire  device  setting
     or writing to memory. It is the equivalent of

	    echo value > filepath

     in the owfs (1) filesystem.

   owget
     owget (1) is a convenience program, combining the function of owdir (1) and
     owread (1) by first trying to read the argument as a directory, and if that
     fails as a 1-wire property.

STANDARD OPTIONS
   --autoserver
     Find  an owserver using the Service Discovery protocol. Essentially Apple's
     Bonjour (aka zeroconf). Only the first owserver  will  be	used,  and  that
     choice is probably arbitrary.

   -s [host:]port
     Connect  via  tcp	(network)  to an owserver process that is connected to a
     physical 1-wire bus. This allows multiple processes to share the same  bus.
     The owserver process can be local or remote.

     If the server option is not specified, the default is the local machine and
     the  IANA	allocated  default port of 4304. Thus "-s localhost:4304" is the
     equivalent.

DATA OPTIONS
--hex
     Hexadecimal mode. For reading data, each byte of  character  will	be  dis-
     played  as  two characrters 0-9ABCDEF. Most useful for reading memory loca-
     tions. No spaces between data.

     Writing data in hexadecimal mode just means that the data should  be  given
     as one long hexadecimal string.

--start=offset
     Read  or write memory locations starting at the offset byte rather than the
     beginning. An offset of 0 means the beginning (and is the default).

--size=bytes
     Read up to the specified number of bytes of a memory location.

HELP OPTIONS
   -h --help
     Shows (this) basic summary of options.

   -V --version
     Version of this program.

DISPLAY OPTIONS
   --dir
     Modify the display of directories to indicate which entries are also direc-
     tories. A directory member will have a trailing '/' if it	is  a  directory
     itself. This aids recursive searches.

   -f --format f[.]i[[.]c]
     Display  format  for  the 1-wire devices. Each device has a 8 byte address,
     consisting of:

     f	    family code, 1 byte

     i	    ID number, 6 bytes

     c	    CRC checksum, 1 byte

     Possible formats are f.i (default, 01.A1B2C3D4E5F6), fi fic f.ic f.i.c  and
     fi.c

     All  formats are accepted as input, but the output will be in the specified
     format.

EXAMPLE
     owdir -s 3000 --format fic
	    Get the device listing (full 16 hex digits, no dots) from the  local
	    owserver at port 3000

     owread -F --autoserver 51.125499A32000/typeK/temperature
	    Read  temperature from the DS2751-based thermocouple on an auto-dis-
	    covered owserver Temperature in fahrenheit.

     owwrite -s 10.0.1.2:3001 32.000800AD23110/pages/page.1 "Passed"
	    Connect to a OWFS server process ( owserver ) that	was  started  on
	    another machine at tcp port 3001 and write to the memory of a DS2780

SEE ALSO
   Programs
     owfs  (1)	owhttpd (1) owftpd (1) owserver (1) owdir (1) owread (1) owwrite
     (1) owpresent (1) owtap (1)

   Configuration and testing
     owfs (5) owtap (1) owmon (1)

   Language bindings
     owtcl (3) owperl (3) owcapi (3)

   Clocks
     DS1427 (3) DS1904(3) DS1994 (3) DS2404 (3) DS2404S (3)  DS2415  (3)  DS2417
     (3)

   ID
     DS2401 (3) DS2411 (3) DS1990A (3)

   Memory
     DS1982  (3)  DS1985  (3) DS1986 (3) DS1991 (3) DS1992 (3) DS1993 (3) DS1995
     (3) DS1996 (3) DS2430A (3) DS2431 (3) DS2433  (3)	DS2502	(3)  DS2506  (3)
     DS28E04 (3) DS28EC20 (3)

   Switches
     DS2405 (3) DS2406 (3) DS2408 (3) DS2409 (3) DS2413 (3) DS28EA00 (3)

   Temperature
     DS1822  (3) DS1825 (3) DS1820 (3) DS18B20 (3) DS18S20 (3) DS1920 (3) DS1921
     (3) DS1821 (3) DS28EA00 (3) DS28E04 (3)

   Humidity
     DS1922 (3)

   Voltage
     DS2450 (3)

   Resistance
     DS2890 (3)

   Multifunction (current, voltage, temperature)
     DS2436 (3) DS2437 (3) DS2438 (3) DS2751 (3) DS2755 (3)  DS2756  (3)  DS2760
     (3) DS2770 (3) DS2780 (3) DS2781 (3) DS2788 (3) DS2784 (3)

   Counter
     DS2423 (3)

   LCD Screen
     LCD (3) DS2408 (3)

   Crypto
     DS1977 (3)

   Pressure
     DS2406 (3) -- TAI8570

AVAILABILITY
     http://www.owfs.org

AUTHOR
     Paul Alfille (paul.alfille@gmail.com)

OWSHELL Manpage 		      2004			      OWSHELL(1)

Want to link to this manual page? Use this URL:
<https://man.freebsd.org/cgi/man.cgi?query=owget&sektion=1&manpath=FreeBSD+Ports+15.1.quarterly>

home | help